/*
 *	$Id$
 */

#ifndef  __MKF_8BIT_CONV_H__
#define  __MKF_8BIT_CONV_H__


#include  "mkf_conv.h"


mkf_conv_t *  mkf_koi8_r_conv_new(void) ;

mkf_conv_t *  mkf_koi8_u_conv_new(void) ;

mkf_conv_t *  mkf_koi8_t_conv_new(void) ;

mkf_conv_t *  mkf_georgian_ps_conv_new(void) ;

mkf_conv_t *  mkf_cp1250_conv_new(void) ;

mkf_conv_t *  mkf_cp1251_conv_new(void) ;

mkf_conv_t *  mkf_cp1252_conv_new(void) ;

mkf_conv_t *  mkf_cp1253_conv_new(void) ;

mkf_conv_t *  mkf_cp1254_conv_new(void) ;

mkf_conv_t *  mkf_cp1255_conv_new(void) ;

mkf_conv_t *  mkf_cp1256_conv_new(void) ;

mkf_conv_t *  mkf_cp1257_conv_new(void) ;

mkf_conv_t *  mkf_cp1258_conv_new(void) ;

mkf_conv_t *  mkf_cp874_conv_new(void) ;

mkf_conv_t *  mkf_viscii_conv_new(void) ;

mkf_conv_t *  mkf_iscii_assamese_conv_new(void) ;

mkf_conv_t *  mkf_iscii_bengali_conv_new(void) ;

mkf_conv_t *  mkf_iscii_gujarati_conv_new(void) ;

mkf_conv_t *  mkf_iscii_hindi_conv_new(void) ;

mkf_conv_t *  mkf_iscii_kannada_conv_new(void) ;

mkf_conv_t *  mkf_iscii_malayalam_conv_new(void) ;

mkf_conv_t *  mkf_iscii_oriya_conv_new(void) ;

mkf_conv_t *  mkf_iscii_punjabi_conv_new(void) ;

mkf_conv_t *  mkf_iscii_roman_conv_new(void) ;

mkf_conv_t *  mkf_iscii_tamil_conv_new(void) ;

mkf_conv_t *  mkf_iscii_telugu_conv_new(void) ;


#endif
